==> nocc-1.9.5.txz: usr/local/www/nocc/lang/sr-ec.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: sr-ec.php 2602 2014-03-31 22:00:26Z siebrand $
 */
/** Serbian (Cyrillic script) (српски (ћирилица)‎)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Charmed94
 * @author Rancher
 * @author Михајло Анђелковић
 */

$lang_locale = 'sr_RS.UTF-8';
$lang_dir = 'ltr';
$default_date_format = '%d.%m.%Y.';
$no_locale_date_format = '%d.%m.%Y.';
$default_time_format = '%H:%M';
$err_user_empty = 'Нисте навели корисничко име';
$err_passwd_empty = 'Нисте навели лозинку';
$alt_delete = 'Обриши изабране поруке';
$alt_delete_one = 'Обриши поруку';
$alt_new_msg = 'Нове поруке';
$alt_reply = 'Одговори пошиљаоцу';
$alt_reply_all = 'Одговори свима';
$alt_forward = 'Проследи';
$alt_next = 'Следећа';
$alt_prev = 'Претходна';
$title_next_page = 'Следећа страница';
$title_prev_page = 'Претходна страница';
$title_next_msg = 'Следећа порука';
$title_prev_msg = 'Претходна порука';
$html_theme_label = 'Тема:';
$html_welcome = 'Добро дошли на %1$s';
$html_login = 'Пријави ме';
$html_user_label = 'Корисничко име:';
$html_passwd_label = 'Лозинка:';
$html_submit = 'Пошаљи';
$html_help = 'Помоћ';
$html_server_label = 'Сервер:';
$html_wrong = 'Корисничко име или лозинка су неисправни';
$html_retry = 'Покушај поново';
$html_remember = 'Сачувај поставке';
$html_lang_label = 'Језик:';
$html_msgperpage_label = 'Број порука по страници:';
$html_preferences = 'Поставке';
$html_full_name_label = 'Пуно име:';
$html_email_address_label = 'Е-адреса:';
$html_bccself = 'Bcc себи';
$html_hide_addresses = 'Сакриј адресе';
$html_outlook_quoting = 'Навођење у стилу Аутлука';
$html_reply_to = 'Одговори на';
$html_reply_to_label = 'Одговори на:';
$html_use_signature = 'Користи потпис';
$html_signature = 'Потпис';
$html_signature_label = 'Потпис:';
$html_reply_leadin_label = 'Уведен блок одговора:';
$html_prefs_updated = 'Поставке су ажуриране';
$html_manage_folders_link = 'Управљање IMAP фасциклама';
$html_manage_filters_link = 'Управљање филтерима е-поште';
$html_use_graphical_smilies = 'Користи смешке';
$html_sent_folder_label = 'Копирај послате поруке у предвиђену фасциклу:';
$html_trash_folder_label = 'Премести обрисане поруке у предвиђену фасциклу:';
$html_colored_quotes = 'Обојени цитати';
$html_display_struct = 'Прикажи састављен текст';
$html_send_html_mail = 'Пошаљи поруку у формату HTML';
$html_folders = 'Фасцикле';
$html_folders_create_failed = 'Не могу да направим фасциклу.';
$html_folders_sub_failed = 'Не могу да вас пријавим на фасциклу.';
$html_folders_unsub_failed = 'Не могу да вас одјавим из фасцикле.';
$html_folders_rename_failed = 'Не могу да преименујем фасциклу.';
$html_folders_updated = 'Фасцикле су ажуриране';
$html_folder_subscribe = 'Пријави ме на';
$html_folder_rename = 'Преименуј';
$html_folder_create = 'Направи нову фасциклу под називом';
$html_folder_remove = 'Одјави ме из';
$html_folder_delete = 'Обриши';
$html_folder_to = 'у';
$html_filter_remove = 'Обриши';
$html_filter_body = 'Садржај поруке';
$html_filter_subject = 'Наслов';
$html_filter_to = 'Поље „за“';
$html_filter_cc = 'Поље cc';
$html_filter_from = 'Поље „од“';
$html_filter_change_tip = 'Ако желите да промените филтер, једноставно га замените.';
$html_reapply_filters = 'Поново примени све филтере';
$html_filter_contains = 'садржи';
$html_filter_name = 'Назив филтера';
$html_filter_action = 'Радња филтера';
$html_filter_moveto = 'Премести у';
$html_select_one = '– изаберите –';
$html_and = 'и';
$html_new_msg_in = 'Нове поруке у';
$html_or = 'или';
$html_move = 'Премести';
$html_copy = 'Копирај';
$html_messages_to = 'изабране поруке у';
$html_gotopage = 'Иди на страницу';
$html_gotofolder = 'Иди у фасциклу';
$html_other_folders = 'Списак фасцикли';
$html_page = 'Страница';
$html_of = 'од';
$html_view_header = 'Прикажи заглавље';
$html_remove_header = 'Сакриј заглавље';
$html_inbox = 'Примљене';
$html_new_msg = 'Састави';
$html_reply = 'Одговори';
$html_reply_short = 'Одг:';
$html_reply_all = 'Одговори свима';
$html_forward = 'Проследи';
$html_forward_short = 'Просл:';
$html_forward_info = 'Прослеђена порука ће бити послата као прилог ове поруке.';
$html_delete = 'Обриши';
$html_new = 'Ново';
$html_mark = 'Обриши';
$html_att_label = 'Прилог:';
$html_atts_label = 'Прилози:';
$html_unknown = '(непознато)';
$html_part_x = 'Део %s';
$html_attach = 'Закачи';
$html_attach_forget = 'Морате приложити датотеку пре слања поруке.';
$html_attach_delete = 'Уклони изабрано';
$html_attach_none = 'Морате приложити датотеку.';
$html_sort_by = 'Поређај по';
$html_sort = 'Поређај';
$html_from = 'Од';
$html_from_label = 'Од:';
$html_subject = 'Наслов';
$html_subject_label = 'Наслов:';
$html_date = 'Датум';
$html_date_label = 'Датум:';
$html_sent_label = 'Послато:';
$html_wrote = 'је написао';
$html_size = 'Величина';
$html_totalsize = 'Укупна величина';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'бајтова';
$html_filename = 'Назив датотеке';
$html_to = 'За';
$html_to_label = 'За:';
$html_cc = 'Примерак';
$html_cc_label = 'Примерак:';
$html_bcc_label = 'Скривени примерак:';
$html_nosubject = 'Без наслова';
$html_send = 'Пошаљи';
$html_cancel = 'Откажи';
$html_no_mail = 'Нема нових порука.';
$html_logout = 'Одјави ме';
$html_msg = 'Порука';
$html_msgs = 'Поруке';
$html_configuration = 'Сервер није исправно подешен.';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Најнижи';
$html_low = 'Низак';
$html_normal = 'Нормалан';
$html_high = 'Висок';
$html_highest = 'Највиши';
$html_flagged = 'Означена';
$html_spam = 'Непожељне поруке';
$html_spam_warning = 'Ова порука је означена као непожељна.';
$html_receipt = 'Захтевај потврду о пријему';
$html_select = 'Изабери';
$html_select_all = 'Обрни одабир';
$html_select_contacts = 'Изаберите контакте';
$html_loading_image = 'Учитавам слике';
$html_send_confirmed = 'Ваша порука је прихваћена за доставу';
$html_no_sendaction = 'Нема одређене радње. Пробајте да омогућите јаваскрипт.';
$html_error_occurred = 'Дошло је до грешке';
$html_prefs_file_error = 'Не могу да запишем поставке.';
$html_wrap = 'Број знакова пре него што пређем у нови ред (одлазне поруке):';
$html_wrap_none = 'Без преламања';
$html_usenet_separator = 'Јузнет раздвајач („-- \n“) пре потписа';
$html_mark_as = 'Означи као';
$html_read = 'прочитано';
$html_unread = 'непрочитано';
$html_encoding_label = 'Кодни распоред:';
$html_add = 'Додај';
$html_contacts = '%1$s контакти';
$html_modify = 'Измени';
$html_back = 'Назад';
$html_contact_add = 'Додај нови контакт';
$html_contact_mod = 'Измени контакт';
$html_contact_first = 'Име';
$html_contact_last = 'Презиме';
$html_contact_nick = 'Надимак';
$html_contact_mail = 'Е-пошта';
$html_contact_list = 'Списак контаката члана %1$s';
$html_contact_del = 'са списка контаката';
$html_contact_count = '%1$d контакти';
$html_contact_err1 = 'Највећи број контаката је „%1$d“';
$html_contact_err2 = 'Не можете додати нови контакт';
$html_contact_err3 = 'Немате права да приступите списку контаката';
$html_contact_none = 'Не могу да пронађем контакте.';
$html_del_msg = 'Обрисати изабране поруке?';
$html_down_mail = 'Преузми';
$original_msg = '– изворна порука –';
$to_empty = 'Поље „За“ не може остати празно.';
$html_images_warning = 'Слике нису приказане ради ваше безбедности.';
$html_images_display = 'Прикажи слике';
$html_smtp_error_no_conn = 'Не могу да отворим везу SMTP';
$html_smtp_error_unexpected = 'Неочекивани одговор SMTP:';
$lang_could_not_connect = 'Не могу да се повежем са сервером';
$lang_invalid_msg_num = 'Неисправан број поруке';
$html_file_upload_attack = 'Могући напад преко отпремања датотеке';
$html_invalid_email_address = 'Неисправна е-адреса';
$html_invalid_msg_per_page = 'Неисправан број порука по страници';
$html_invalid_wrap_msg = 'Неисправна ширина преламања поруке';
$html_seperate_msg_win = 'Поруке у засебном прозору';
$html_err_file_contacts = 'Не могу да запишем контакте.';
$html_session_file_error = 'Не могу да запишем сесију.';
$html_login_not_allowed = 'Не можете се повезати с овим корисничким именом.';
$lang_err_send_delay = 'Морате сачекати између две поруке (%1$d сек.)';
$html_search = 'Претражи';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/sr-ec.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: sr-ec.php 2660 2016-01-27 09:35:17Z siebrand $
 */
/** Serbian (Cyrillic script) (српски (ћирилица)‎)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Charmed94
 * @author Rancher
 * @author Srdjan m
 * @author Михајло Анђелковић
 * @author Сербијана
 */

$lang_locale = 'sr_RS.UTF-8';
$lang_dir = 'ltr';
$default_date_format = '%d.%m.%Y.';
$no_locale_date_format = '%d.%m.%Y.';
$default_time_format = '%H:%M';
$err_user_empty = 'Нисте навели корисничко име';
$err_passwd_empty = 'Нисте навели лозинку';
$alt_delete = 'Обриши изабране поруке';
$alt_delete_one = 'Обриши поруку';
$alt_new_msg = 'Нове поруке';
$alt_reply = 'Одговори пошиљаоцу';
$alt_reply_all = 'Одговори свима';
$alt_forward = 'Проследи';
$alt_next = 'Следећа';
$alt_prev = 'Претходна';
$title_next_page = 'Следећа страница';
$title_prev_page = 'Претходна страница';
$title_next_msg = 'Следећа порука';
$title_prev_msg = 'Претходна порука';
$html_theme_label = 'Тема:';
$html_welcome = 'Добро дошли на %1$s';
$html_login = 'Пријави ме';
$html_user_label = 'Корисничко име:';
$html_passwd_label = 'Лозинка:';
$html_submit = 'Пошаљи';
$html_help = 'Помоћ';
$html_server_label = 'Сервер:';
$html_wrong = 'Корисничко име или лозинка су неисправни';
$html_retry = 'Покушај поново';
$html_remember = 'Сачувај поставке';
$html_lang_label = 'Језик:';
$html_msgperpage_label = 'Број порука по страници:';
$html_preferences = 'Поставке';
$html_full_name_label = 'Пуно име:';
$html_email_address_label = 'Имејл адреса:';
$html_bccself = 'Bcc себи';
$html_hide_addresses = 'Сакриј адресе';
$html_outlook_quoting = 'Навођење у стилу Аутлука';
$html_reply_to = 'Одговори на';
$html_reply_to_label = 'Одговори на:';
$html_use_signature = 'Користи потпис';
$html_signature = 'Потпис';
$html_signature_label = 'Потпис:';
$html_reply_leadin_label = 'Уведен блок одговора:';
$html_prefs_updated = 'Поставке су ажуриране';
$html_manage_folders_link = 'Управљање IMAP фасциклама';
$html_manage_filters_link = 'Управљање филтерима имејла';
$html_use_graphical_smilies = 'Користи смешке';
$html_sent_folder_label = 'Копирај послате поруке у предвиђену фасциклу:';
$html_trash_folder_label = 'Премести обрисане поруке у предвиђену фасциклу:';
$html_colored_quotes = 'Обојени цитати';
$html_display_struct = 'Прикажи састављен текст';
$html_send_html_mail = 'Пошаљи поруку у формату HTML';
$html_folders = 'Фасцикле';
$html_folders_create_failed = 'Не могу да направим фасциклу.';
$html_folders_sub_failed = 'Не могу да вас пријавим на фасциклу.';
$html_folders_unsub_failed = 'Не могу да вас одјавим из фасцикле.';
$html_folders_rename_failed = 'Не могу да преименујем фасциклу.';
$html_folders_updated = 'Фасцикле су ажуриране';
$html_folder_subscribe = 'Пријави ме на';
$html_folder_rename = 'Преименуј';
$html_folder_create = 'Направи нову фасциклу под називом';
$html_folder_remove = 'Одјави ме из';
$html_folder_delete = 'Обриши';
$html_folder_to = 'у';
$html_filter_remove = 'Обриши';
$html_filter_body = 'Садржај поруке';
$html_filter_subject = 'Наслов';
$html_filter_to = 'Поље „за“';
$html_filter_cc = 'Поље cc';
$html_filter_from = 'Поље „од“';
$html_filter_change_tip = 'Ако желите да промените филтер, једноставно га замените.';
$html_reapply_filters = 'Поново примени све филтере';
$html_filter_contains = 'садржи';
$html_filter_name = 'Назив филтера';
$html_filter_action = 'Радња филтера';
$html_filter_moveto = 'Премести у';
$html_select_one = '– изаберите –';
$html_and = 'и';
$html_new_msg_in = 'Нове поруке у';
$html_or = 'или';
$html_move = 'Премести';
$html_copy = 'Копирај';
$html_messages_to = 'изабране поруке у';
$html_gotopage = 'Иди на страницу';
$html_gotofolder = 'Иди у фасциклу';
$html_other_folders = 'Списак фасцикли';
$html_page = 'Страница';
$html_of = 'од';
$html_view_header = 'Прикажи заглавље';
$html_remove_header = 'Сакриј заглавље';
$html_inbox = 'Примљене';
$html_new_msg = 'Састави';
$html_reply = 'Одговори';
$html_reply_short = 'Одг:';
$html_reply_all = 'Одговори свима';
$html_forward = 'Проследи';
$html_forward_short = 'Просл:';
$html_forward_info = 'Прослеђена порука ће бити послата као прилог ове поруке.';
$html_delete = 'Обриши';
$html_new = 'Ново';
$html_mark = 'Обриши';
$html_att_label = 'Прилог:';
$html_atts_label = 'Прилози:';
$html_unknown = '(непознато)';
$html_part_x = 'Део %s';
$html_attach = 'Закачи';
$html_attach_forget = 'Морате приложити датотеку пре слања поруке.';
$html_attach_delete = 'Уклони изабрано';
$html_attach_none = 'Морате приложити датотеку.';
$html_sort_by = 'Поређај по';
$html_sort = 'Поређај';
$html_from = 'Од';
$html_from_label = 'Од:';
$html_subject = 'Наслов';
$html_subject_label = 'Наслов:';
$html_date = 'Датум';
$html_date_label = 'Датум:';
$html_sent_label = 'Послато:';
$html_wrote = 'је написао';
$html_quote_wrote = 'На %1$s %2$s, %3$s написао је:';
$html_size = 'Величина';
$html_totalsize = 'Укупна величина';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'бајтова';
$html_filename = 'Назив датотеке';
$html_to = 'За';
$html_to_label = 'За:';
$html_cc = 'Примерак';
$html_cc_label = 'Примерак:';
$html_bcc_label = 'Скривени примерак:';
$html_nosubject = 'Без наслова';
$html_send = 'Пошаљи';
$html_cancel = 'Откажи';
$html_no_mail = 'Нема нових порука.';
$html_logout = 'Одјави ме';
$html_msg = 'Порука';
$html_msgs = 'Поруке';
$html_configuration = 'Сервер није исправно подешен.';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Најнижи';
$html_low = 'Низак';
$html_normal = 'Нормалан';
$html_high = 'Висок';
$html_highest = 'Највиши';
$html_flagged = 'Означена';
$html_spam = 'Непожељне поруке';
$html_spam_warning = 'Ова порука је означена као непожељна.';
$html_receipt = 'Захтевај потврду о пријему';
$html_select = 'Изабери';
$html_select_all = 'Обрни одабир';
$html_select_contacts = 'Изаберите контакте';
$html_loading_image = 'Учитавам слике';
$html_send_confirmed = 'Ваша порука је прихваћена за доставу';
$html_no_sendaction = 'Нема одређене радње. Пробајте да омогућите јаваскрипт.';
$html_error_occurred = 'Дошло је до грешке';
$html_prefs_file_error = 'Не могу да запишем поставке.';
$html_wrap = 'Број знакова пре него што пређем у нови ред (одлазне поруке):';
$html_wrap_none = 'Без преламања';
$html_usenet_separator = 'Јузнет раздвајач („-- \n“) пре потписа';
$html_mark_as = 'Означи као';
$html_read = 'прочитано';
$html_unread = 'непрочитано';
$html_encoding_label = 'Кодни распоред:';
$html_add = 'Додај';
$html_contacts = '%1$s контакти';
$html_modify = 'Измени';
$html_back = 'Назад';
$html_contact_add = 'Додај нови контакт';
$html_contact_mod = 'Измени контакт';
$html_contact_first = 'Име';
$html_contact_last = 'Презиме';
$html_contact_nick = 'Надимак';
$html_contact_mail = 'Имејл';
$html_contact_list = 'Списак контаката члана %1$s';
$html_contact_del = 'са списка контаката';
$html_contact_count = '%1$d контакти';
$html_contact_err1 = 'Највећи број контаката је „%1$d“';
$html_contact_err2 = 'Не можете додати нови контакт';
$html_contact_err3 = 'Немате права да приступите списку контаката';
$html_contact_none = 'Не могу да пронађем контакте.';
$html_contact_ruler_top = 'На врху';
$html_contact_listcheck_title = 'Обележите како бисте додали имејл на списак.';
$html_contact_list_add = 'Додај на списак';
$html_contact_listname = 'Име списка';
$html_contact_listonly = 'Само списци';
$html_contact_all = 'Прикажи све';
$html_contact_add_confirm = 'Додај имејлове на постојећи списак?';
$html_del_msg = 'Обрисати изабране поруке?';
$html_down_mail = 'Преузми';
$original_msg = '– изворна порука –';
$to_empty = 'Поље „За“ не може остати празно.';
$html_images_warning = 'Слике нису приказане ради ваше безбедности.';
$html_images_display = 'Прикажи слике';
$html_smtp_error_no_conn = 'Не могу да отворим везу SMTP';
$html_smtp_error_unexpected = 'Неочекивани одговор SMTP:';
$lang_could_not_connect = 'Не могу да се повежем са сервером';
$lang_invalid_msg_num = 'Неисправан број поруке';
$html_file_upload_attack = 'Могући напад преко отпремања датотеке';
$html_invalid_email_address = 'Неисправна имејл адреса';
$html_invalid_msg_per_page = 'Неисправан број порука по страници';
$html_invalid_wrap_msg = 'Неисправна ширина преламања поруке';
$html_seperate_msg_win = 'Поруке у засебном прозору';
$html_err_file_contacts = 'Не могу да запишем контакте.';
$html_session_file_error = 'Не могу да запишем сесију.';
$html_login_not_allowed = 'Не можете се повезати с овим корисничким именом.';
$lang_err_send_delay = 'Морате сачекати између две поруке (%1$d сек.)';
$html_search = 'Претражи';
$html_new_session = 'Следећа сесија';
$html_fd_filename = 'Преузми %1$s';
$html_fd_mailcount = 'Тренутно {{PLURAL:$1|0=нема е-поште|1=има %1$d е-порука|има %1$d е-порука}} у фасцикли.';
$html_fd_mailskip = 'Следеће е-поруке неће бити део mbox датотеке, пошто ће да превазиђу ограничење меморије php-а:';
$html_fd_filesize = 'величина %1$d';
$html_fd_skipcount = 'са %1$d е-порука';
$html_fd_largefolder = 'Зависно од ваше брзине преузимања, ово преузимање може бити неуспешно зато што је скрипта престала да ради.<br /> Проверите да ли је преузимање у потпуности завршено или подесите max_execution_time на већу вредност у датотеци php.ini.';
$reset_clicked = 'Да ли стварно желите да обришете овај формулар?';
$html_send_recover = 'Пријавите се како бисте вратили изгубљени нацрт!';
$html_send_discard = 'Кликните овде како бисте одбацили сачувани нацрт.';
$html_collect_label = 'Аутоматски сачувај имејл адресе:';
$html_collect_option0 = 'Никад';
$html_collect_option1 = 'Само за одлазеће е-поруке';
$html_collect_option2 = 'Само за отворене е-поруке';
$html_collect_option3 = 'Увек';
